# Changelog

## [1.0.0] - 2025-01-23

### Added

- Initial release
- 550+ SLICOT routines (AB, SB, MB, IB, TG, SG families)
- Pre-built wheels: Linux (x86_64, aarch64), macOS (arm64), Windows (AMD64, ARM64)
- Python 3.11-3.13, NumPy 2.x
- Type stubs (PEP 561)
